==> moodle_1.3.1.orig.tar.gz: moodle/lang/fi/dialogue.php <==
<?PHP // $Id: dialogue.php,v 1.4 2004/03/24 15:04:59 paca70 Exp $ 
      // dialogue.php - created with Moodle 1.2 Beta +++ (2004031300)


$string['addmynewentries'] = 'Lis viestini';
$string['addmynewentry'] = 'Lis viestini';
$string['addsubject'] = 'Lis aihe';
$string['allowmultiple'] = 'Avoimet vuoropuhelut henkil kohden';
$string['allowstudentdialogues'] = 'Salli vuoropuhelut opiskelijoiden vlill';
$string['close'] = 'Sulje';
$string['closed'] = 'Suljettu';
$string['confirmclosure'] = 'Olet sulkemassa vuoropuhelua $a:n kanssa. Suljettuja vuoropuheluja ei voida avata uudelleen. Jos suljet tmn vuoropuhelun, voit katsella merkintj, mutta et voi en list siihen mitn.<br /><br />Oletko varma, ett haluat sulkea keskustelun?';
$string['deleteafter'] = 'Poista suljetut tmn ajan kuluttua (piviss)';
$string['dialogueclosed'] = 'Vuoropuhelu suljettu';
$string['dialogueintro'] = 'Vuoropuhelun kuvaus';
$string['dialoguemail'] = '$a->userform on lisnnyt viestin vuoropuheluunne \'$a->dialogue\'

Net listyt viestit osoitteessa $a->url';
$string['dialoguemailhtml'] = '$a->userform on lisnnyt viestin vuoropuheluunne \'<i>$a->dialogue</i>\'<br /><br />

Net listyt viestit osoitteessa <a href=\"$a->url\">vuoropuhelu</a>.';
$string['dialoguename'] = 'Vuoropuhelun nimi';
$string['dialogueopened'] = 'Vuoropuhelu aukaistu $a :lle';
$string['dialoguewith'] = 'Vuoropuhelu $a:n kanssa';
$string['everybody'] = 'Kaikki';
$string['furtherinformation'] = 'Listietoja';
$string['lastentry'] = 'Viimeisin viesti';
$string['maildefault'] = 'Shkpostin oletusasetus';
$string['modulename'] = 'Vuoropuhelu';
$string['modulenameplural'] = 'Vuoropuhelut';
$string['namehascloseddialogue'] = '$a on sulkenut vuoropuhelun';
$string['newdialogueentries'] = 'Uudet viestit';
$string['newentry'] = 'Uusi viesti';
$string['noavailablepeople'] = 'Ei henkilit, joiden kanssa vuoropuhelu voidaan aloittaa';
$string['nopersonchosen'] = 'Henkil ei ole valittu!';
$string['nosubject'] = 'Aihe puuttuu!';
$string['notextentered'] = 'Teksti puttuu!';
$string['notstarted'] = 'Et ole aloittanut tt vuoropuhelua viel';
$string['notyetseen'] = 'Avaamatta';
$string['numberofentries'] = 'Viestien mr';
$string['numberofentriesadded'] = '$a :n viestit';
$string['of'] = '/';
$string['onwrote'] = '$a kirjoitti';
$string['onyouwrote'] = '$a kirjoitit';
$string['open'] = 'Avaa';
$string['openadialoguewith'] = 'Avaa vuoropuhelu';
$string['opendialogue'] = 'Avaa vuoropuhelu';
$string['opendialogueentries'] = 'Avaa vuoropuhelun viestit';
$string['pane0'] = 'Avaa vuoropuhelu';
$string['pane1'] = '$a vuoropuhelua odottaa vastauksiasi';
$string['pane1one'] = '1 vuoropuhelu odottaa vastaustasi';
$string['pane2'] = '$a vuoropuhelua odottaa vastausta toiselta henkilt';
$string['pane2one'] = '1 vuoropuhelu odottaa vastausta toiselta henkillt';
$string['pane3'] = '$a suljettua vuoropuhelua';
$string['pane3one'] = '1 suljettu vuoropuhelu';
$string['seen'] = 'Avattu $a sitten';
$string['sendmailmessages'] = 'Lhet shkpostiviesti uusista viesteistni';
$string['status'] = 'Tila';
$string['studenttostudent'] = 'Opiskelija opiskelijalle';
$string['subject'] = 'Aihe';
$string['subjectadded'] = 'Aihe listty';
$string['teachertostudent'] = 'Opettaja opiskelijalle';
$string['typefirstentry'] = 'Kirjoita ensinminen viesti thn';
$string['typefollowup'] = 'Kirjoita seuraavat thn';
$string['typeofdialogue'] = 'Vuoropuhelun tyyppi';
$string['typereply'] = 'Kirjoita vastaus thn';
$string['viewallentries'] = 'Nyt $a vuoropuhelun viesti';

?>

==> moodle_1.4.4.dfsg.1.orig.tar.gz: moodle/lang/fi/dialogue.php <==
<?PHP // $Id$ 
      // dialogue.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2004101900)


$string['addmynewentries'] = 'Lis viestini';
$string['addmynewentry'] = 'Lis viestini';
$string['addsubject'] = 'Lis aihe';
$string['allowmultiple'] = 'Avoimet vuoropuhelut henkil kohden';
$string['allowstudentdialogues'] = 'Salli vuoropuhelut opiskelijoiden vlill';
$string['close'] = 'Sulje';
$string['closed'] = 'Suljettu';
$string['confirmclosure'] = 'Olet sulkemassa vuoropuhelua $a:n kanssa. Suljettuja vuoropuheluja ei voida avata uudelleen. Jos suljet tmn vuoropuhelun, voit katsella merkintj, mutta et voi en list siihen mitn.<br /><br />Oletko varma, ett haluat sulkea keskustelun?';
$string['deleteafter'] = 'Poista suljetut tmn ajan kuluttua (piviss)';
$string['dialogueclosed'] = 'Vuoropuhelu suljettu';
$string['dialogueintro'] = 'Vuoropuhelun kuvaus';
$string['dialoguemail'] = '$a->userform on lisnnyt viestin vuoropuheluunne \'$a->dialogue\'

Net listyt viestit osoitteessa $a->url';
$string['dialoguemailhtml'] = '$a->userform on lisnnyt viestin vuoropuheluunne \'<i>$a->dialogue</i>\'<br /><br />

Net listyt viestit osoitteessa <a href=\"$a->url\">vuoropuhelu</a>.';
$string['dialoguename'] = 'Vuoropuhelun nimi';
$string['dialogueopened'] = 'Vuoropuhelu aukaistu $a :lle';
$string['dialoguewith'] = 'Vuoropuhelu $a:n kanssa';
$string['everybody'] = 'Kaikki';
$string['furtherinformation'] = 'Listietoja';
$string['lastentry'] = 'Viimeisin viesti';
$string['maildefault'] = 'Shkpostin oletusasetus';
$string['mailnotification'] = 'Shkposti-ilmoitus';
$string['modulename'] = 'Vuoropuhelu';
$string['modulenameplural'] = 'Vuoropuhelut';
$string['namehascloseddialogue'] = '$a on sulkenut vuoropuhelun';
$string['newdialogueentries'] = 'Uudet viestit';
$string['newentry'] = 'Uusi viesti';
$string['noavailablepeople'] = 'Ei henkilit, joiden kanssa vuoropuhelu voidaan aloittaa';
$string['nopersonchosen'] = 'Henkil ei ole valittu!';
$string['nosubject'] = 'Aihe puuttuu!';
$string['notextentered'] = 'Teksti puttuu!';
$string['notstarted'] = 'Et ole aloittanut tt vuoropuhelua viel';
$string['notyetseen'] = 'Avaamatta';
$string['numberofentries'] = 'Viestien mr';
$string['numberofentriesadded'] = '$a :n viestit';
$string['of'] = '/';
$string['onwrote'] = '$a kirjoitti';
$string['onyouwrote'] = '$a kirjoitit';
$string['open'] = 'Avaa';
$string['openadialoguewith'] = 'Avaa vuoropuhelu';
$string['opendialogue'] = 'Avaa vuoropuhelu';
$string['opendialogueentries'] = 'Avaa vuoropuhelun viestit';
$string['pane0'] = 'Avaa vuoropuhelu';
$string['pane1'] = '$a vuoropuhelua odottaa vastauksiasi';
$string['pane1one'] = '1 vuoropuhelu odottaa vastaustasi';
$string['pane2'] = '$a vuoropuhelua odottaa vastausta toiselta henkilt';
$string['pane2one'] = '1 vuoropuhelu odottaa vastausta toiselta henkillt';
$string['pane3'] = '$a suljettua vuoropuhelua';
$string['pane3one'] = '1 suljettu vuoropuhelu';
$string['seen'] = 'Avattu $a sitten';
$string['sendmailmessages'] = 'Lhet shkpostiviesti uusista viesteistni';
$string['status'] = 'Tila';
$string['studenttostudent'] = 'Opiskelija opiskelijalle';
$string['subject'] = 'Aihe';
$string['subjectadded'] = 'Aihe listty';
$string['teachertostudent'] = 'Opettaja opiskelijalle';
$string['thischarset'] = 'iso-8859-1';
$string['thisdirection'] = 'ltr';
$string['thislanguage'] = 'Suomi';
$string['typefirstentry'] = 'Kirjoita ensinminen viesti thn';
$string['typefollowup'] = 'Kirjoita seuraavat thn';
$string['typeofdialogue'] = 'Vuoropuhelun tyyppi';
$string['typereply'] = 'Kirjoita vastaus thn';
$string['viewallentries'] = 'Nyt $a vuoropuhelun viesti';

?>
